@@ -308,8 +308,8 @@ static gboolean
 glade_base_editor_get_child_selected (GladeBaseEditor *e, GtkTreeIter *iter)
 {
   GtkTreeSelection *sel =
-      gtk_tree_view_get_selection (GTK_TREE_VIEW (e->priv->treeview));
-  return gtk_tree_selection_get_selected (sel, NULL, iter);
+    gtk_tree_view_get_selection (GTK_TREE_VIEW (e->priv->treeview));
+  return (sel) ? gtk_tree_selection_get_selected (sel, NULL, iter) : FALSE;
 }
 
 /* Forward declaration for glade_base_editor_project_widget_name_changed */
